extern crate chrono;
extern crate clap;
extern crate curl;
extern crate env_logger;
#[macro_use]
extern crate log;
extern crate serde;
extern crate serde_json;
#[macro_use]
extern crate serde_derive;
extern crate toml;
extern crate url;
extern crate xdg;

mod config;
mod gog;
mod http;
mod models;

use config::Config;
use clap::{Arg, App};
use gog::Gog;
use http::Http;

fn main() {
    env_logger::init().unwrap();

    let matches = App::new("Gog Synchronizer")
        .version("0.1.0")
        .author("Sebastian Hugentobler <sebastian@vanwa.ch>")
        .about("Synchronizes your gog library to a local folder.")
        .arg(Arg::with_name("storage")
            .short("s")
            .long("storage")
            .value_name("FOLDER")
            .help("Sets the download folder (defaults to the working directory).")
            .takes_value(true))
        .get_matches();

    let download_folder = matches.value_of("storage").unwrap_or(".");

    let config = Config::new();

    let mut http_client = Http::new();
    let mut gog = Gog::new(&mut http_client);
    gog.login().unwrap();
    gog.sync(download_folder).unwrap();
}
